#!/bin/sh

if ! which realpath > /dev/null ; then
    echo "Please install the realpath program." 1>&2
    exit 1
fi

THISDIR=`dirname "$0"`
DIRNAME=`realpath "$THISDIR/.."`
PROGNAME=`basename "$0"`

UNIFONT='/usr/share/unifont/unifont.hex'

if [ "$1" = '--help' ] ; then
    cat 1>&2 <<EOF
Usage: $PROGNAME [ -q ]

Find font usage and generate the necessary binary font files. Currently, only
GNU Unifont is supported.

The optional -q argument indicates quiet execution, suppressing all output.
EOF
    exit 1
fi

# Detect quiet operation.

if [ "$1" = '-q' ] ; then
    QUIET="$1"
    shift 1
else
    QUIET=
fi

# Find all needed fonts and generate them.

for NEEDED in `find "$DIRNAME/pkg" -name '*.tff.needed'` ; do
    TARGETDIR=`dirname "$NEEDED"`
    FONTFILE=`basename "$NEEDED" .needed`
    FONTNAME=`basename "$FONTFILE" .tff`

    FONTPATH="$TARGETDIR/$FONTFILE"

    if [ -e "$FONTPATH" ] ; then
        if [ ! "$QUIET" ] ; then
            echo "Exists, not generated: $FONTPATH" 1>&2
        fi
        continue
    fi

    if [ "$FONTNAME" != 'unifont' ] ; then
        if [ ! "$QUIET" ] ; then
            echo "Unrecognised ($FONTNAME), not generated: $FONTPATH" 1>&2
        fi
        continue
    fi

    if [ ! "$QUIET" ] ; then
        echo "$FONTPATH"
    fi
    "$THISDIR/readfont.py" "$UNIFONT" "$FONTPATH"
done
